# Xi-CAM SAXS

Xi-CAM GUI plugin that facilitates data exploration and processing for SAXS experiments.

(Work in progress, release 1.0.0 will be more stable.)

## Installation

The latest build of Xi-cam.SAXS is available on pypi as `xicam.SAXS`.

### Details

If unsure about where to install, we recommend creating an environment.
There are several tools that provide this, such as virtualenv or conda.

For more details about setting up an environment for installation, see the
[Xi-CAM Installation Instructions](https://xi-cam.readthedocs.io/en/latest/quickstart.html#install-xi-cam)
for your operating system.

Once your environment is activated, install with the following command:

```
pip install xicam.SAXS
```

(this will install xicam for you as well).


## Resources

For more information about Xi-CAM, see the [main Xi-CAM repository's README](https://github.com/xi-cam/xi-cam)

## Release Notes

* 0.3.0 - Refactoring; provides Calibration and Correlation stages.

